---
title: "Plato, Parmenides, and the Theory of Forms - Part 3"
date: 2018-09-29T21:53:42Z
tags: ["eidos","forms","idealism","realism","mind","transcendence"]
topics: ["philosophy"]
image: img/firmament-as-form.jpg
draft: false
---

To recap and summarize, there are three different kinds of forms presented to us in the Parmenides, by Socrates:

1. *Relational:* the subjective experience of qualities of things, relative to each other. For example, Bigness, Sameness, or Heaviness (and their oppositions: Smallness, Difference, or Lightness).
2. *Ontological:* the model or exemplar of actual things. For example, Man, Animal, Fire, and Water (but, inexplicably, not things like sticks and stones and mud and sealing wax).
3. *Ethical:* Truthfulness, Goodness, Beautifulness, and Justness. This conception is the one that has the most traction, at least with later neoplatonic followers (e.g. Plotinus and Olympiodorus).

And, as we saw with the last post, there were three basic theories for the existence of these forms:

1. *Literal ideas:* concepts in the mind, that have no ontological status beyond the mind, out of which all things are materialized.
2. *Patterns in nature:* something similar to a blacksmith’s mould, or an artists miniature, from which all things are copied.
3. *Noumenal entities:* Universal transcendental beings, in which all particulars participate.

As we’ll see here, Parmenides is careful to move fluidly between these three kinds, and these three theories, in order to make his case against the young Socrates, and his Forms. Depending on the author, and the level of complexity of the analysis, some parse Parmenides’ case into four objections, some five, and some six. For the sake of limiting the difficulty of this post, I’ll be taking the four objection approach, clustering the minor ones in where they make sense. I’ll go through each of Parmenides’ objections as they occur in the course of the dialogue, and considering whether he’s sufficiently refuted Socrates.

**Objection 1: Reconciling Unity with Plurality**
The first of the objections Parmenides raises, is to challenge Socrates to account for how the Forms – as unities – can manifest themselves severally in concrete particulars. He is essentially asking Socrates to reconcile unity with plurality. If the whole Form is present in a single particular, then it cannot be present in any other particular. Yet, if only a portion of the Form is present in all particulars manifesting it, then we have a divisible object which cannot be a Form, because said entities must be perfect, and perfection requires indivisible unity.

Socrates rebuttal to this, is to say that the Forms are like the day, which is at once everywhere and experienced severally by everyone, and yet the same whole day. This seems plausible at first glance, but Parmenides has a rejoinder to offer. He changes the metaphor to a sail, and insists that no one covered by it is covered by the whole, and therefore, the sail must have parts. Taking Bigness as his example from this metaphor, Parmenides then argues that breaking bigness into necessarily smaller parts to be distributed among the particular people who manifest bigness, would render the Form of Bigness an absurdity.

While Parmenides’ initial objection is a good point (how can we reconcile unity and plurality), the exchange in the dialogue on this point is frustrating and disappointing. Firstly, Parmenides changes the metaphor from the day to a sail with no justification or explanation. This completely muddles Socrates’ original point. To restate his case in modern terms: I experience Tuesday in Chicago, and you experience Tuesday in New York, but it would be laughingly absurd to suggest that we are experiencing *different days*. Equally, it would be just as absurd to say that because I am in Chicago and you in New York, we are experiencing *different parts of the same day*. It is the same day everywhere that day is taking place. Parmenides moves to the sail metaphor, because he realizes it is less obviously absurd to talk about different parts of a large piece of sail cloth. This is because a *day* and a *sail* are fundamentally different in kind, and it is this shift is that makes Parmenides’ next step in the objection plausible. If we accept that it is only parts of the sail that are covering each particular individual, then we must accept that it is only parts of Bigness that are in each big person, thus ostensibly demonstrating the incommensurability of “participation” in the unified Form of Bigness. On the original metaphor, however, accepting that there are “parts” is not necessary to accepting participation in a given day. While the term “participation” may be somewhat inadequate to the task of describing a big person’s relationship to the Form of Bigness, it certainly doesn’t require the divisibility of Bigness any more than our separate participation in Tuesday requires the divisibility of Tuesday.

So, Parmenides’ first major complaint turns out to be a confusion on his part. Whether this was intentional or not is a matter of debate. Some speculate that Plato was putting the confusions of the Aristotelian splitters in the Academy into the mouth of Parmenides. Perhaps this is true. Regardless, it’s clear there is a way to understand the Forms as a harmonization of unity and plurality, in the sense conceived of by Socrates original metaphor. As such, this objection is not enough to dismiss the theory of Forms.

**Objection 2: The Relational Regress on Bigness**
Next, Parmenides attempts to show that the Forms (of the relational kind), lead to a regress. He argues that a Form of Bigness, in which big things necessarily participate (and are called “big” by their participation) must itself belong to a class of objects in which the Form of Bigness and big particulars are all members. This is because, on Parmenides’ view, there must be something against which we can compare the Form of Bigness with big things, to see that they are similar. This, then, would require yet another class of objects that contains the compared Form of Bigness and big things, and another comparator Form of classes containing the Form of Bigness and big things, ad infinitum.

Again, at first glance, this seems devastating to the theory. Socrates attempts to escape this by reformulating Forms as pure thoughts. This is something talked about in part two of this series, and I’ll come back to this in a moment, but first, let’s have a closer look at the regress. There are two problems that I see with Parmenides’ complaint, here. First, Parmenides is confusing universals and particulars. There is nothing to suggest that, because Forms have an ontological status outside the mind, they must share the same constraints and features as the particulars they characterize. Forms, if they exist, do not exist in the material, ever-changing, finite world of sensible experience. So, why must a Form have a Form? Particulars, of course, derive their reality from Forms. But the reality of the Forms themselves is necessarily independent, because they are perfect. What’s more, being perfect unities, they must be uniques. There can only be one Form of Bigness, necessarily, and it stands necessarily as the originator (the arché?) of all particular sensible objects that we call “big”. It makes no sense to call the Form of Bigness “big”, itself, because that would require it to participate in itself. Participation entails being a particular, and only sensible things can be particulars (and being particular, necessarily would require it to be imperfect, because copy). So, Parmenides’ regress turns out to be implausible.

Getting back to Socrates’ notion of the Forms as ideas in the mind only, there is only final speculation I’d like to offer. Presently, there is no good explanation for how it is that all of experience – indeed, all of the order of reality – isn’t just a “blooming, buzzing confusion” (to borrow James’ famous phrase). Human minds are somehow capable of discerning patterns and definitions and organizing experiences into discrete, ordered objects. How is this possible? Is it part of the fabric of reality itself, these discrete patterns and this intelligible order? If that is true, and it’s also true that only a conscious mind is capable of apprehending these things, then is it really that much of a stretch to speculate a “mind” or “consciousness” as a property of the universe itself, out of which the Forms arise (or whatever ordering pattern suits your fancy)? Perhaps this is some form of Genetic Fallacy or Composition Fallacy, but without an explanation for how this is so, the speculation seems plausible to me. On this view, Socrates’ suggestion that the Forms may be “only in the mind” might work, if we extend the notion of “mind” to some kind of property of the universe itself. But I’m willing to concede this as just a speculation.

**Objection 3: Relational Regress Redux (Likeness)**
This objection is often explained as a reiteration of the Largeness regress. If particulars with the same property are like each other because they participate in a Form of Likeness, then the particulars and the Form of Likeness must be like each other, and that would itself require another Form of Likeness of Forms of Likeness and Particulars, and so on. In addition to the points I raised in the first iteration of this problem, this objection also suffers from not actually addressing Socrates’ next reconceptualization of the theory. Socrates is not suggesting a participation or presence of any immanent character with the notion of forms as “patterns in nature”. Rather, he is likening the Forms to the moulds in an artisan’s workshop, or the miniatures in an artists studio. This would make the similarities seen in particulars in nature a product of their similarity with the mould out of which they were “pressed”. This is a very different concept, than the noumenal entities deconstructed in the first and second objections. In the context of Socrates’ time, this metaphor has some plausibility. Why is it that the planets have a spherical shape, or move in near-circular paths? Why do living creatures exhibit symmetry of physical form? Why is there water or earth or fire at all? Something must have “pressed” these objects into existence, and provided the copying mechanism for nature to continue to do the work on its own. These days, we have loads of scientific explanations for how this actually happens, but at the time, Parmenides would have had a hard time objecting to this line of theorizing — which is why he chose to argue against Likeness, as if he were arguing against the conception of Bigness before it.

**Objection 4: Separated At Birth**
The separation objection is perhaps the most important, and arguably the second most famous of all Parmenides’ objections to the Forms. This objection, as Gill rightly points out, rests on Socrates’ failure to adequately explain “participation” in any of the previous objections. The objection comes down to this: the Forms can only relate to each other, and particulars can only relate to each other, but particulars cannot relate to the Forms, and the Forms cannot relate to particulars. Therefore, even if they did exist, the Forms would have no relevance to the existence of particulars. I find the objection, from an ontological perspective, unconvincing for two reasons. First, as I’ve explained above, Parmenides appears to be engaging in a great deal of sleight of hand in his objections. He is using the relational kind when it suits him, the noumenal conception when it suits him, and the ontological kind, when it suits him. I suppose you could respond that the variety in Socrates’ theory is itself enough to discount the theory as unworkable; after all, what exactly are we talking about, here? Which combination of these things are we to take as canonical? I’m inclined to agree. What’s more, I think the Separation argument does have some teeth, as an epistemological problem. Even if the Forms exist, and even if we could defend the notion of “participation”, there remains the problem of how we can know any of this is actually the case. As put by Gill,

> “…if things in our realm can be known and explained without reference to Forms, and if we are fully empowered within our realm, how much have we lost if we give up Forms…? …they seem irrelevant…”

Indeed. In Socrates’ metaphysics, the Forms are absolutely essential. The Forms are causally necessary for things being as they appear to us. As Gill puts it, “immanent character accounts for appearances”, and the Forms account for immanent character. But if, because the realm of Forms is indeed inaccessible to us (either intelligibly or sensibly), because timeless and perfect entities cannot be known by finite, changing beings, then we cannot know the ultimate reality of the immanent characters we apprehend with our senses, and it indeed seems we are trapped in a cartesian hell of varying degrees of uncertainty and vagueness. Quoting Gill again, “remove the causal link, as Parmenides does, in the Separation argument, and we no longer have access to what things *really are*.”

**Conclusion**
The Forms, it turns out, are only pointers to a much deeper problem that we are often willing to admit. Plato was attempting to bridge the gap between subjective experience, and objective reality; between appearance, and substance; between moral sentiment, and mathematical certainty; between what is, and what ought to be; and he was hoping to do it in one motion with the invention of The Forms. All of the basic questions: what is happening when I identify something as “beautiful”? How do I know that someone is “good”? Why am I able to have the concept of a “person”? The Forms were supposed to give us insight into all these things. But, if we can’t even know what the Forms themselves are, we can’t possibly answer any of the other questions with any certainty or honesty. In the end, it is this last objection that kills the theory for me, as nothing more than an interesting speculation. It’s one of the reasons why I find Kant’s work so unconvincing. He runs head-first into the noumenal for much of his work on ethics, and as we’ve seen here, it is far from clear what that is.

```[imported from exitingthecave.com on 30 November 2021]```

